@@ -12,10 +12,17 @@
 # You should have received a copy of the GNU General Public License along with
 # PRAW.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Provides the code to load PRAW's configuration file `praw.ini`."""
+
 import os
 import sys
 
-from praw.compat import configparser  # pylint: disable-msg=E0611
+try:
+    import ConfigParser as configparser
+except ImportError:
+    # pylint: disable-msg=F0401
+    import configparser  # NOQA
+    # pylint: enable-msg=F0401
 
 
 def _load_configuration():
